==> nv-wx-srv-eng-1.0.20.tgz: package/eng.js <==
const _url             = require("url");
const _path            = require("path");
const _str             = require("nv-string-basic");
const {OASGN,J2S,jdcp} = require("nv-facutil-basic");
const _S               = require("nv-server-simple-stream").http.simple;
const _clk             = globalThis.CLOCK.clock;     


const _err             = require("./err");

const DFLT_WX_APP_ID_NAME                     = "___wx_app_id___";
const DFLT_WX_APP_SECRET_NAME                 = "___wx_app_secret___";

const DFLT_WX_MCH_ID_NAME                          = "___wx_mch_id___";
const DFLT_WX_HONGBAO_SEND_TOTAL_NUM_NAME          = "___wx_hongbao_send_total_num___";
const DFLT_WX_HONGBAO_SEND_SEND_NAME_NAME          = "___wx_hongbao_send_send_name___";
const DFLT_WX_HONGBAO_SEND_WISHING_NAME            = "___wx_hongbao_send_wishing___";
const DFLT_WX_HONGBAO_SEND_ACT_NAME_NAME           = "___wx_hongbao_send_act_name___";
const DFLT_WX_HONGBAO_SEND_REMARK_NAME             = "___wx_hongbao_send_remark___";
const DFLT_WX_HONGBAO_SEND_SCENE_ID_NAME           = "___wx_hongbao_send_scene_id___";
const DFLT_WX_HONGBAO_SEND_MOBILE$RISK_INFO_NAME   =  "___wx_hongbao_send_mobile@risk_info___";
const DFLT_WX_HONGBAO_SENF_DEVICEID$RISK_INFO_NAME =  "___wx_hongbao_send_deviceid@risk_info___";


const DFLT_WX_HONGBAO_RETRY_MIN_INTV_NAME     = "___wx_hongbao_retry_min_intv___";      // 
const DFLT_WX_HONGBAO_SEND_FREQ_NAME          = "___wx_hongbao_send_freq___";



const DFLT_NGINX_USER             = "www-data";
const DFLT_USOCK                  = "___nv_wx_srv___";


const DFLT_CONSTS = ()=>({
    usock:DFLT_USOCK,
    nginx_user:DFLT_NGINX_USER,
    wx_app_id_name:DFLT_WX_APP_ID_NAME,
    wx_app_secret_name:DFLT_WX_APP_SECRET_NAME,
    ////
    wx_mch_id_name:DFLT_WX_MCH_ID_NAME,
    wx_hongbao_send_total_num_name:DFLT_WX_HONGBAO_SEND_TOTAL_NUM_NAME,
    wx_hongbao_send_send_name_name:DFLT_WX_HONGBAO_SEND_SEND_NAME_NAME,
    wx_hongbao_send_wishing_name:DFLT_WX_HONGBAO_SEND_WISHING_NAME,
    wx_hongbao_send_act_name_name:DFLT_WX_HONGBAO_SEND_ACT_NAME_NAME,
    wx_hongbao_send_remark_name:DFLT_WX_HONGBAO_SEND_REMARK_NAME,
    wx_hongbao_send_scene_id_name:DFLT_WX_HONGBAO_SEND_SCENE_ID_NAME,
    wx_hongbao_send_mobile$risk_info_name:DFLT_WX_HONGBAO_SEND_MOBILE$RISK_INFO_NAME,
    wx_hongbao_send_deviceid$risk_info_name:DFLT_WX_HONGBAO_SENF_DEVICEID$RISK_INFO_NAME,
    ////
    wx_hongbao_retry_min_intv_name:DFLT_WX_HONGBAO_RETRY_MIN_INTV_NAME,
    wx_hongbao_send_freq_name:DFLT_WX_HONGBAO_SEND_FREQ_NAME,
});

const DFLT_ROUTE_PREFIX           = "/third_party/wx";
const ROUTED                      = ()=>{
    let prefix=DFLT_ROUTE_PREFIX;
    let d = {}
    d[`${prefix}/change_wx_cfg`]     = 'change_wx_cfg';
    d[`${prefix}/get_openid`]        = 'get_openid';
    return(d)
}
                     

const DFLT_404_HANDLE = async(D,res,srv) => {
    let r = await _S.reply_with_json(res,[false,[-4040,_err[-4040]]]);
    return(r)
}

const DFLT_ROUTE_NOT_EXIST = async(D,res,srv) => {
    let r = await _S.reply_with_json(res,[false,[-4041,_err[-4041]]]);
    return(r)
}


const DFLT_VALIDATE = async(reqD,route,srv) => {
     let req_headers = reqD.headers;
     ////let req_body    = _cmmn.buf2json(reqD.body);
     let USER        = srv.user;
     let {u,ka}      = USER.tpool;
     let userid      = req_headers.utoken?u.get_userid(req_headers.utoken):undefined;
     if(userid) {
         let is_debug = (userid === '/___未划分___/___debug___');
         let is_admin = (userid === '/___未划分___/admin');
         if(is_debug || is_admin) {
             if(route.includes("change_wx_cfg")) {
                 if(is_debug) {
                     return([true,userid])
                 } else {
                     return([false,"权限不足"])
                 }
             } else {
                 return([true,userid]) 
             }
         } else {
             if(
                 route.includes("change_wx_cfg") ||
                 route.includes("send_hongbao")
             ) {
                 return([false,"权限不足"])
             } else if(route.includes("get_openid")) {
                 return([true,userid])
             } else {
                 return([false,"路由不支持"])
             }
         }
     } else {
         return([false,"未登录"])
     }
}

module.exports = {
    DFLT_WX_MCH_ID_NAME,
    DFLT_WX_HONGBAO_SEND_TOTAL_NUM_NAME,
    DFLT_WX_HONGBAO_SEND_SEND_NAME_NAME,
    DFLT_WX_HONGBAO_SEND_WISHING_NAME,  
    DFLT_WX_HONGBAO_SEND_ACT_NAME_NAME,
    DFLT_WX_HONGBAO_SEND_REMARK_NAME, 
    DFLT_WX_HONGBAO_SEND_SCENE_ID_NAME,
    DFLT_WX_HONGBAO_SEND_MOBILE$RISK_INFO_NAME,   
    DFLT_WX_HONGBAO_SENF_DEVICEID$RISK_INFO_NAME, 
    DFLT_WX_APP_ID_NAME,DFLT_WX_APP_SECRET_NAME,
    DFLT_WX_HONGBAO_RETRY_MIN_INTV_NAME,DFLT_WX_HONGBAO_SEND_FREQ_NAME,
   ////
    DFLT_NGINX_USER,DFLT_USOCK,
    DFLT_CONSTS,
   ////
   DFLT_ROUTE_PREFIX,       ROUTED,
   DFLT_404_HANDLE,         DFLT_ROUTE_NOT_EXIST,
   DFLT_VALIDATE,
}

==> nv-wx-srv-eng-1.0.21.tgz: package/eng.js <==
const _url             = require("url");
const _path            = require("path");
const _str             = require("nv-string-basic");
const {OASGN,J2S,jdcp} = require("nv-facutil-basic");
const _S               = require("nv-server-simple-stream").http.simple;
const _clk             = globalThis.CLOCK.clock;     


const _err             = require("./err");

const DFLT_WX_APP_ID_NAME                     = "___wx_app_id___";
const DFLT_WX_APP_SECRET_NAME                 = "___wx_app_secret___";

const DFLT_WX_MCH_ID_NAME                     = "___wx_mch_id___";
const DFLT_WX_MCH_KEY_NAME                    = "___wx_mch_key___";

const DFLT_WX_API_PEM_KEY_NAME                = "___wx_api_pem_key___";      
const DFLT_WX_API_PEM_CERT_NAME               = "___wx_api_pem_cert___";

const DFLT_WX_HONGBAO_SEND_TOTAL_NUM_NAME          = "___wx_hongbao_send_total_num___";
const DFLT_WX_HONGBAO_SEND_SEND_NAME_NAME          = "___wx_hongbao_send_send_name___";
const DFLT_WX_HONGBAO_SEND_WISHING_NAME            = "___wx_hongbao_send_wishing___";
const DFLT_WX_HONGBAO_SEND_ACT_NAME_NAME           = "___wx_hongbao_send_act_name___";
const DFLT_WX_HONGBAO_SEND_REMARK_NAME             = "___wx_hongbao_send_remark___";
const DFLT_WX_HONGBAO_SEND_SCENE_ID_NAME           = "___wx_hongbao_send_scene_id___";
const DFLT_WX_HONGBAO_SEND_MOBILE$RISK_INFO_NAME   =  "___wx_hongbao_send_mobile@risk_info___";
const DFLT_WX_HONGBAO_SENF_DEVICEID$RISK_INFO_NAME =  "___wx_hongbao_send_deviceid@risk_info___";


const DFLT_WX_HONGBAO_RETRY_MIN_INTV_NAME     = "___wx_hongbao_retry_min_intv___";      // 
const DFLT_WX_HONGBAO_SEND_FREQ_NAME          = "___wx_hongbao_send_freq___";



const DFLT_NGINX_USER             = "www-data";
const DFLT_USOCK                  = "___nv_wx_srv___";


const DFLT_CONSTS = ()=>({
    usock:DFLT_USOCK,
    nginx_user:DFLT_NGINX_USER,
    wx_app_id_name:DFLT_WX_APP_ID_NAME,
    wx_app_secret_name:DFLT_WX_APP_SECRET_NAME,
    ////
    wx_mch_id_name       :DFLT_WX_MCH_ID_NAME,
    wx_mch_key_name      :DFLT_WX_MCH_KEY_NAME,
    wx_api_pem_key_name  :DFLT_WX_API_PEM_KEY_NAME,
    wx_api_pem_cert_name :DFLT_WX_API_PEM_CERT_NAME,
    wx_hongbao_send_total_num_name:DFLT_WX_HONGBAO_SEND_TOTAL_NUM_NAME,
    wx_hongbao_send_send_name_name:DFLT_WX_HONGBAO_SEND_SEND_NAME_NAME,
    wx_hongbao_send_wishing_name:DFLT_WX_HONGBAO_SEND_WISHING_NAME,
    wx_hongbao_send_act_name_name:DFLT_WX_HONGBAO_SEND_ACT_NAME_NAME,
    wx_hongbao_send_remark_name:DFLT_WX_HONGBAO_SEND_REMARK_NAME,
    wx_hongbao_send_scene_id_name:DFLT_WX_HONGBAO_SEND_SCENE_ID_NAME,
    wx_hongbao_send_mobile$risk_info_name:DFLT_WX_HONGBAO_SEND_MOBILE$RISK_INFO_NAME,
    wx_hongbao_send_deviceid$risk_info_name:DFLT_WX_HONGBAO_SENF_DEVICEID$RISK_INFO_NAME,
    ////
    wx_hongbao_retry_min_intv_name:DFLT_WX_HONGBAO_RETRY_MIN_INTV_NAME,
    wx_hongbao_send_freq_name:DFLT_WX_HONGBAO_SEND_FREQ_NAME,
});

const DFLT_ROUTE_PREFIX           = "/third_party/wx";
const ROUTED                      = ()=>{
    let prefix=DFLT_ROUTE_PREFIX;
    let d = {}
    d[`${prefix}/change_wx_cfg`]     = 'change_wx_cfg';
    d[`${prefix}/get_openid`]        = 'get_openid';
    return(d)
}
                     

const DFLT_404_HANDLE = async(D,res,srv) => {
    let r = await _S.reply_with_json(res,[false,[-4040,_err[-4040]]]);
    return(r)
}

const DFLT_ROUTE_NOT_EXIST = async(D,res,srv) => {
    let r = await _S.reply_with_json(res,[false,[-4041,_err[-4041]]]);
    return(r)
}


const DFLT_VALIDATE = async(reqD,route,srv) => {
     let req_headers = reqD.headers;
     ////let req_body    = _cmmn.buf2json(reqD.body);
     let USER        = srv.user;
     let {u,ka}      = USER.tpool;
     let userid      = req_headers.utoken?u.get_userid(req_headers.utoken):undefined;
     if(userid) {
         let is_debug = (userid === '/___未划分___/___debug___');
         let is_admin = (userid === '/___未划分___/admin');
         if(is_debug || is_admin) {
             if(route.includes("change_wx_cfg")) {
                 if(is_debug) {
                     return([true,userid])
                 } else {
                     return([false,"权限不足"])
                 }
             } else {
                 return([true,userid]) 
             }
         } else {
             if(
                 route.includes("change_wx_cfg") ||
                 route.includes("send_hongbao")
             ) {
                 return([false,"权限不足"])
             } else if(route.includes("get_openid")) {
                 return([true,userid])
             } else {
                 return([false,"路由不支持"])
             }
         }
     } else {
         return([false,"未登录"])
     }
}

module.exports = {
    DFLT_WX_MCH_ID_NAME,DFLT_WX_MCH_KEY_NAME,
    DFLT_WX_API_PEM_KEY_NAME,DFLT_WX_API_PEM_CERT_NAME,
    DFLT_WX_HONGBAO_SEND_TOTAL_NUM_NAME,
    DFLT_WX_HONGBAO_SEND_SEND_NAME_NAME,
    DFLT_WX_HONGBAO_SEND_WISHING_NAME,  
    DFLT_WX_HONGBAO_SEND_ACT_NAME_NAME,
    DFLT_WX_HONGBAO_SEND_REMARK_NAME, 
    DFLT_WX_HONGBAO_SEND_SCENE_ID_NAME,
    DFLT_WX_HONGBAO_SEND_MOBILE$RISK_INFO_NAME,   
    DFLT_WX_HONGBAO_SENF_DEVICEID$RISK_INFO_NAME, 
    DFLT_WX_APP_ID_NAME,DFLT_WX_APP_SECRET_NAME,
    DFLT_WX_HONGBAO_RETRY_MIN_INTV_NAME,DFLT_WX_HONGBAO_SEND_FREQ_NAME,
   ////
    DFLT_NGINX_USER,DFLT_USOCK,
    DFLT_CONSTS,
   ////
   DFLT_ROUTE_PREFIX,       ROUTED,
   DFLT_404_HANDLE,         DFLT_ROUTE_NOT_EXIST,
   DFLT_VALIDATE,
}
